Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2144)

Unified Diff: apk_minter/src/org/chromium/apkminter/APKMinting.java

Issue 1948033005: Rename MintingExample.template.apk to WebApk.template.apk (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « apk_minter/assets/WebApk.template.apk ('k') | build/android/rezip/RezipApk.java » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: apk_minter/src/org/chromium/apkminter/APKMinting.java
diff --git a/apk_minter/src/org/chromium/apkminter/APKMinting.java b/apk_minter/src/org/chromium/apkminter/APKMinting.java
index 2399232bbd9769cc13965056a265cb025554afbb..e509611324173cf380fc2c9f6e66e4689b4a3cb5 100644
--- a/apk_minter/src/org/chromium/apkminter/APKMinting.java
+++ b/apk_minter/src/org/chromium/apkminter/APKMinting.java
@@ -49,8 +49,8 @@ import kellinwood.security.zipsigner.ZipSigner;
* modified and generate new APK for the request site, and signing the APK.
*/
public class APKMinting {
- private static final String MINTING_APK_PREFIX = "org.chromium.minting";
- private static final String TEMPLATE_APK_NAME = "MintingExample.template.apk";
+ private static final String MINTING_APK_PREFIX = "org.chromium.webapk";
+ private static final String TEMPLATE_APK_NAME = "WebApk.template.apk";
private static final String KEY_STORE_NAME = "minted-apk-release-key-bks";
private static final String KEY_STORE_ALIAS = "minted_apk";
private static final String KEY_STORE_PASSWORD = "chrome";
@@ -213,7 +213,7 @@ public class APKMinting {
// A temporary directory with a unique name is created for each request.
// The structure of this directory is:
// --tmp.apk: a copy of MintingExample.template.apk loaded from assets.
// --/gen: includes all the files after unzip the tmp.apk.
// --tmp.unsigned.apk: zip the directory "gen" after modifying its
// AndroidManifest.xml and res folder.
@@ -213,7 +213,7 @@ public class APKMinting {
// A temporary directory with a unique name is created for each request.
// The structure of this directory is:
- // --tmp.apk: a copy of MintingExample.template.apk loaded from assets.
+ // --tmp.apk: a copy of WebApk.template.apk loaded from assets.
// --/gen: includes all the files after unzip the tmp.apk.
// --tmp.unsigned.apk: zip the directory "gen" after modifying its
« no previous file with comments | « apk_minter/assets/WebApk.template.apk ('k') | build/android/rezip/RezipApk.java » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698